==> react-atom-progress-bar-2.6.0.tgz: package/lib/ProgressBarLine/index.js <==
import PropTypes from 'prop-types';
import cx from 'classnames';
import Line from './Line.js';
import { BASE_CLASS, CLASS_CONTAINER_BAR, BASE_CLASS_LINE_SIMPLE, BASE_CLASS_LINE_DOUBLE } from './settings.js';
import useIndicator from './useIndicator.js';
import usePercentage from './usePercentage.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var ProgressBarLine = function ProgressBarLine(_ref) {
  var hideIndicator = _ref.hideIndicator,
      indicatorBottom = _ref.indicatorBottom,
      indicatorTotal = _ref.indicatorTotal,
      isAnimatedOnChange = _ref.isAnimatedOnChange,
      percentage = _ref.percentage,
      mainBarPercentage = _ref.mainBarPercentage,
      extraBarPercentage = _ref.extraBarPercentage;
  var percentageArray = usePercentage({
    percentage: percentage,
    mainBarPercentage: mainBarPercentage,
    extraBarPercentage: extraBarPercentage
  });

  var _useIndicator = useIndicator({
    hideIndicator: hideIndicator,
    indicatorBottom: indicatorBottom,
    percentage: percentageArray[0],
    indicatorTotal: indicatorTotal
  }),
      indicatorTopElement = _useIndicator[0],
      indicatorBottomElement = _useIndicator[1];

  return /*#__PURE__*/_jsxs("div", {
    className: BASE_CLASS,
    children: [!hideIndicator && !indicatorBottom && indicatorTopElement, /*#__PURE__*/_jsx("div", {
      className: CLASS_CONTAINER_BAR,
      children: percentageArray.map(function (percentageValue, currentIndex, array) {
        var _cx;

        var index = array.length - 1 - currentIndex;
        var isExtra = array.length === 2 && currentIndex === 0;
        return /*#__PURE__*/_jsx(Line, {
          className: cx((_cx = {}, _cx[BASE_CLASS_LINE_SIMPLE] = array.length === 1, _cx[BASE_CLASS_LINE_DOUBLE] = array.length === 2, _cx)),
          isAnimatedOnChange: isAnimatedOnChange,
          percentage: array[index],
          isExtra: isExtra
        }, index);
      })
    }), !hideIndicator && indicatorBottom && indicatorBottomElement]
  });
};

ProgressBarLine.displayName = 'ProgressBarLine';
export default ProgressBarLine;

==> react-atom-progress-bar-2.8.0.tgz: package/lib/ProgressBarLine/index.js <==
import PropTypes from 'prop-types';
import cx from 'classnames';
import { BASE_CLASS, BASE_CLASS_LINE, CLASS_CONTAINER_BAR, BASE_CLASS_LINE_SIMPLE, BASE_CLASS_LINE_DOUBLE } from './settings.js';
import Line from './Line.js';
import useIndicator from './useIndicator.js';
import usePercentage from './usePercentage.js';
import { SIZES, STATUS } from '../settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var ProgressBarLine = function ProgressBarLine(_ref) {
  var _cx;

  var hideIndicator = _ref.hideIndicator,
      indicatorBottom = _ref.indicatorBottom,
      indicatorTotal = _ref.indicatorTotal,
      isAnimatedOnChange = _ref.isAnimatedOnChange,
      percentage = _ref.percentage,
      mainBarPercentage = _ref.mainBarPercentage,
      extraBarPercentage = _ref.extraBarPercentage,
      status = _ref.status,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.MEDIUM : _ref$size;
  var percentageArray = usePercentage({
    percentage: percentage,
    mainBarPercentage: mainBarPercentage,
    extraBarPercentage: extraBarPercentage
  });

  var _useIndicator = useIndicator({
    hideIndicator: hideIndicator,
    indicatorBottom: indicatorBottom,
    percentage: percentageArray[0],
    indicatorTotal: indicatorTotal
  }),
      indicatorTopElement = _useIndicator[0],
      indicatorBottomElement = _useIndicator[1];

  return /*#__PURE__*/_jsxs("div", {
    className: BASE_CLASS,
    children: [!hideIndicator && !indicatorBottom && indicatorTopElement, /*#__PURE__*/_jsx("div", {
      className: cx(CLASS_CONTAINER_BAR, (_cx = {}, _cx[CLASS_CONTAINER_BAR + "--size-" + size] = size, _cx)),
      children: percentageArray.map(function (percentageValue, currentIndex, array) {
        var _cx2;

        var index = array.length - 1 - currentIndex;
        var isExtra = array.length === 2 && currentIndex === 0;
        return /*#__PURE__*/_jsx(Line, {
          className: cx((_cx2 = {}, _cx2[BASE_CLASS_LINE_SIMPLE] = array.length === 1, _cx2[BASE_CLASS_LINE_DOUBLE] = array.length === 2, _cx2[BASE_CLASS_LINE + "--status-" + status] = status, _cx2)),
          isAnimatedOnChange: isAnimatedOnChange,
          percentage: array[index],
          isExtra: isExtra
        }, index);
      })
    }), !hideIndicator && indicatorBottom && indicatorBottomElement]
  });
};

ProgressBarLine.displayName = 'ProgressBarLine';
export default ProgressBarLine;
